pub fn is_opencode_child_session(row: &LocalSessionRow) -> boolExpand description
Return true when a cached row corresponds to an OpenCode child session.
pub fn is_opencode_child_session(row: &LocalSessionRow) -> boolReturn true when a cached row corresponds to an OpenCode child session.